from pathlib import Path

from uploader.domain.domain import TestRun
from uploader.upload import create_parser
from uploader.utils.zipper import find_files


def test_find_files():
    parser = create_parser()
    args = parser.parse_args(['-tr', r'.*\.xml'])

    test_run = TestRun(args=args)
    result = find_files(test_run, Path('tests/fixtures/test_results/'))
    elements = [
        'tests/fixtures/test_results/pydriller_testresults.xml',
        'tests/fixtures/test_results/examples/pydriller_testresults.xml',
        'tests/fixtures/test_results/examples1/pydriller_testresults1.xml',
        'tests/fixtures/test_results/examples1/examples2/' +
        'pydriller_testresults2.xml',
    ]
    for el in elements:
        assert el in result
    assert len(elements) == len(result)


def test_find_files_exclude_dir():
    parser = create_parser()
    args = parser.parse_args(['-tr', r'.*\.xml'])

    test_run = TestRun(args=args)
    result = find_files(test_run, Path('tests/fixtures/test_results_exclude_dirs/'))
    elements = [
        'tests/fixtures/test_results_exclude_dirs/pydriller_testresults.xml',
    ]
    for el in elements:
        assert el in result
    assert len(elements) == len(result)


def test_find_files_with_config():
    parser = create_parser()
    args = parser.parse_args(['-tr', r'.*\.xml', '-cf', '.testpulse.yaml'])

    test_run = TestRun(args=args)
    result = find_files(test_run, Path('tests/fixtures/test_results/'))
    elements = [
        'tests/fixtures/test_results/.testpulse.yaml',
        'tests/fixtures/test_results/pydriller_testresults.xml',
        'tests/fixtures/test_results/examples/pydriller_testresults.xml',
        'tests/fixtures/test_results/examples1/pydriller_testresults1.xml',
        'tests/fixtures/test_results/examples1/examples2/' +
        'pydriller_testresults2.xml',
    ]
    for el in elements:
        assert el in result
    assert len(elements) == len(result)



import os
import responses

from pathlib import Path
from unittest import mock

from uploader.domain.domain import TestRun
from uploader.upload import create_parser
from uploader.receiver.receiver import upload_test_results
from uploader.utils.urls import ENDPOINT_UPLOAD_RESULTS, TESTPULSE_RECEIVER

env_variables_mocked = {
    "GITHUB_REPOSITORY": "testpulse/myrepo",
    "GITHUB_SHA": "0289dbc9db2214d7b3e2a115987c3067b4400f25",
    "GITHUB_REF": "refs/remotes/origin/main",
    "TESTPULSE_TOKEN": "MYVERYLONGANDIMPOSSIBLETOGUESSTOKEN",
    "GITHUB_ACTIONS": "True",
    "GITHUB_RUN_ID": "8159919366",
    "GITHUB_REPOSITORY_OWNER": "testpulse",
    "RUNNER_OS": "Windows",
    "GITHUB_WORKFLOW": "My workflow",
    "GITHUB_JOB": "job1"
}

url = TESTPULSE_RECEIVER + ENDPOINT_UPLOAD_RESULTS


@responses.activate
@mock.patch.dict(os.environ, env_variables_mocked)
def test_simple_false():
    # Register via 'Response' object
    rsp1 = responses.Response(
        method="POST",
        url=url,
        status=404
    )
    responses.add(rsp1)

    parser = create_parser()
    args = parser.parse_args(['-tr', r'.*\.xml'])

    test_run = TestRun(args)
    resp2 = upload_test_results(zip=Path('tests/fixtures/test_results.zip'),
                                test_run=test_run)

    assert resp2 is None


@responses.activate
@mock.patch.dict(os.environ, env_variables_mocked)
def test_simple_true():
    # Register via 'Response' object
    rsp1 = responses.Response(
        method="POST",
        url=url,
        status=200,
        json={"link": "mylink"}
    )
    responses.add(rsp1)

    parser = create_parser()
    args = parser.parse_args(['-tr', r'.*\.xml'])

    test_run = TestRun(args)
    resp2 = upload_test_results(zip=Path('tests/fixtures/test_results.zip'),
                                test_run=test_run)

    assert resp2 == "mylink"



#!/usr/bin/env python3

import argparse
import logging
from pathlib import Path

from uploader.authentication.authentication import authenticate
from uploader.domain.domain import TestRun
from uploader.receiver.receiver import upload_test_results
from uploader.utils.utils import regex_pattern
from uploader.utils.zipper import find_files, zip_files

logging.basicConfig(format='%(asctime)s-%(levelname)s:%(filename)s:%(lineno)d %(message)s', level=logging.INFO)
logger = logging.getLogger(__name__)


def create_parser() -> argparse.ArgumentParser:
    """Parse known test runner arguments.

    Returns:
        argparse.Namespace: namespace of parsed argument values
    """
    parser = argparse.ArgumentParser(
                    prog='receiver.py',
                    description='Upload test results for futher processing',
                    epilog='testpulse-io')

    parser.add_argument(
        "-tr",
        "--test-results-regex",
        required=False,
        help="Regex pattern to find test results XML files",
        type=regex_pattern,
    )

    parser.add_argument(
        "-cr",
        "--coverage-results-regex",
        required=False,
        help="Regex pattern to find coverage results XML files",
        type=regex_pattern,
    )

    parser.add_argument(
        "-os",
        "--operating-system",
        type=str,
        help="OS where the tests run."
    )

    parser.add_argument(
        "-lv",
        "--language-version",
        type=str,
        help="Language version. For example for Python it can be 3.11, 3.12.. For Java, 17, 21, etc.."
    )

    parser.add_argument(
        "-tfv",
        "--test-framework-version",
        type=str,
        help="Version of the test framework. For example, Pytest 8.0.0"
    )

    parser.add_argument(
        "-tt",
        "--test-type",
        type=str,
        choices=['unit', 'integration', 'e2e'],
        default='unit',
        help="Test type"
    )

    parser.add_argument(
        "-cf",
        "--config-file",
        type=str,
        help="Path to the config file."
    )

    parser.add_argument(
        "-t",
        "--token",
        type=str,
        help="Testpulse token."
    )

    parser.add_argument(
        "--only-zip",
        action='store_true',
        help="When set to true, the tool will not upload the zip. Useful to debug the content of the zip file."
    )

    return parser


def run(args: argparse.Namespace) -> None:
    root = Path().resolve()
    test_run = TestRun(args)

    logger.info('Authenticating...')
    authenticate(test_run.organization)
    logger.info('Authenticated successfully.')

    logger.info('Finding files and zipping...')
    selected_files = find_files(test_run, root=root)
    zip_file_name = zip_files(files_list=selected_files, root=root)
    if zip_file_name is None:
        return

    logger.info(f'Saved zip file in {zip_file_name}')

    if args.only_zip:
        logger.info("Stopping here because --only-zip argument was provided.")
        return

    logger.info('Uploading to our backend server...')

    link = upload_test_results(Path(zip_file_name), test_run=test_run)

    if link is not None:
        logger.info('Upload was successful!')
        logger.info('TestPulse URL: ' + link)


def main():
    parser = create_parser()
    args = parser.parse_args()

    if args.test_results_regex is None and args.coverage_results_regex is None:
        parser.error("At least one of --test-results-regex and --coverage-results-regex required")
    run(args=args)


if __name__ == '__main__':
    main()



import os
import responses
import pytest

from unittest import mock

from uploader.authentication.authentication import authenticate
from uploader.domain.exceptions import HTTPRequestFailed
from uploader.utils.urls import ENDPOINT_TOKENS_CHECK, TESTPULSE_API

env_variables_mocked = {
    "GITHUB_REPOSITORY_OWNER": "testpulse-io",
    "TESTPULSE_TOKEN": "MYVERYLONGANDIMPOSSIBLETOGUESSTOKEN",
}

url = TESTPULSE_API + ENDPOINT_TOKENS_CHECK


@responses.activate
@mock.patch.dict(os.environ, env_variables_mocked)
def test_authenticate_404():
    # Register via 'Response' object
    rsp1 = responses.Response(
        method="GET",
        url=url,
        status=404
    )
    responses.add(rsp1)

    with pytest.raises(HTTPRequestFailed, match='The token validation request failed.*'):
        authenticate("testpulse-io")


@responses.activate
@mock.patch.dict(os.environ, env_variables_mocked)
def test_authenticate_valid():
    # Register via 'Response' object
    rsp1 = responses.Response(
        method="GET",
        url=url,
        status=200,
        json={'id': 1234, 'name': 'testpulse-io'}
    )
    responses.add(rsp1)

    authenticate("testpulse-io")
